==> libggi-2.1.1.src.tar.bz2: libggi-2.1.1/programs/demos/banner.inc.c <==
/* $Id: banner.inc.c,v 1.1.2.1 2004/10/18 15:22:41 cegger Exp $
******************************************************************************

   The banner used by Flying-GGIs...

   Authors:	1998 	  Andrew Apted		[andrew@ggi-project.org]

   This software is placed in the public domain and can be used freely
   for any purpose. It comes without any kind of warranty, either
   expressed or implied, including, but not limited to the implied
   warranties of merchantability or fitness for a particular purpose.
   Use it at your own risk. the author is not responsible for any damage
   or consequences raised by use or inability to use this program.

******************************************************************************
*/

/* Image of GGI */

static char *banner[46] = {

"..................###########....................................###########...................................",
"..............###################...##.......................###################...##.......###################",
"............########.......###########.....................########.......###########...........###########....",
"..........#######.............########...................#######.............########............#########.....",
".........######................#######..................######................#######.............#######......",
"........######...................#####.................######...................#####.............#######......",
".......######.....................#####...............######.....................#####............#######......",
"......######......................#####..............######......................#####............#######......",
".....#######.......................####.............#######.......................####............#######......",
"....#######.........................###............#######.........................###............#######......",
"....######..........................###............######..........................###............#######......",
"...#######..........................###...........#######..........................###............#######......",
"...#######...........................##...........#######...........................##............#######......",
"..#######........................................#######..........................................#######......",
"..#######........................................#######..........................................#######......",
".########.......................................########..........................................#######......",
".#######........................................#######...........................................#######......",
".#######........................................#######...........................................#######......",
".#######........................................#######...........................................#######......",
"########.......................................########...........................................#######......",
"########.......................................########...........................................#######......",
"########..................###################..########..................###################......#######......",
"########......................###########......########......................###########..........#######......",
"########.......................#########.......########.......................#########...........#######......",
"########........................########.......########........................########...........#######......",
"########........................#######........########........................#######............#######......",
"########........................#######........########........................#######............#######......",
"#########.......................#######........#########.......................#######............#######......",
".########.......................#######.........########.......................#######............#######......",
".########.......................#######.........########.......................#######............#######......",
".########.......................#######.........########.......................#######............#######......",
"..########......................#######..........########......................#######............#######......",
"..########......................#######..........########......................#######............#######......",
"..#########.....................#######..........#########.....................#######............#######......",
"...########.....................#######...........########.....................#######............#######......",
"....########....................#######............########....................#######............#######......",
"....########....................#######............########....................#######............#######......",
".....########...................#######.............########...................#######............#######......",
"......########..................#######..............########..................#######............#######......",
".......########.................#######...............########.................#######............#######......",
"........########................#######................########................#######............#######......",
"..........########............#########..................########............#########...........#########.....",
"............#########......##########......................#########......##########............###########....",
"..............####################...........................####################...........###################",
"..................############...................................############..................................",

NULL
};

==> libggi2-2.2.2-3-src.tar.bz2: libggi-2.2.2/programs/demos/banner.inc.c <==
/* $Id: banner.inc.c,v 1.3 2005/06/09 19:10:40 cegger Exp $
******************************************************************************

   The banner used by the Flying-GGIs demo.

   Authors:	1998 	  Andrew Apted		[andrew@ggi-project.org]

   This software is placed in the public domain and can be used freely
   for any purpose. It comes without any kind of warranty, either
   expressed or implied, including, but not limited to the implied
   warranties of merchantability or fitness for a particular purpose.
   Use it at your own risk. the author is not responsible for any damage
   or consequences raised by use or inability to use this program.

******************************************************************************
*/

/* Image of GGI */

static const char *banner[46] = {

"..................###########....................................###########...................................",
"..............###################...##.......................###################...##.......###################",
"............########.......###########.....................########.......###########...........###########....",
"..........#######.............########...................#######.............########............#########.....",
".........######................#######..................######................#######.............#######......",
"........######...................#####.................######...................#####.............#######......",
".......######.....................#####...............######.....................#####............#######......",
"......######......................#####..............######......................#####............#######......",
".....#######.......................####.............#######.......................####............#######......",
"....#######.........................###............#######.........................###............#######......",
"....######..........................###............######..........................###............#######......",
"...#######..........................###...........#######..........................###............#######......",
"...#######...........................##...........#######...........................##............#######......",
"..#######........................................#######..........................................#######......",
"..#######........................................#######..........................................#######......",
".########.......................................########..........................................#######......",
".#######........................................#######...........................................#######......",
".#######........................................#######...........................................#######......",
".#######........................................#######...........................................#######......",
"########.......................................########...........................................#######......",
"########.......................................########...........................................#######......",
"########..................###################..########..................###################......#######......",
"########......................###########......########......................###########..........#######......",
"########.......................#########.......########.......................#########...........#######......",
"########........................########.......########........................########...........#######......",
"########........................#######........########........................#######............#######......",
"########........................#######........########........................#######............#######......",
"#########.......................#######........#########.......................#######............#######......",
".########.......................#######.........########.......................#######............#######......",
".########.......................#######.........########.......................#######............#######......",
".########.......................#######.........########.......................#######............#######......",
"..########......................#######..........########......................#######............#######......",
"..########......................#######..........########......................#######............#######......",
"..#########.....................#######..........#########.....................#######............#######......",
"...########.....................#######...........########.....................#######............#######......",
"....########....................#######............########....................#######............#######......",
"....########....................#######............########....................#######............#######......",
".....########...................#######.............########...................#######............#######......",
"......########..................#######..............########..................#######............#######......",
".......########.................#######...............########.................#######............#######......",
"........########................#######................########................#######............#######......",
"..........########............#########..................########............#########...........#########.....",
"............#########......##########......................#########......##########............###########....",
"..............####################...........................####################...........###################",
"..................############...................................############..................................",

NULL
};
